#ifndef OPTIONS_H
#define OPTIONS_H
#include <QtCore>
#include <QtGui>
#include <QtSql>
#include "ui_dialog.h"



class options : public QDialog
{
    Q_OBJECT
public:
    options(QWidget *parent = 0);
    Ui::Dialog ui;
signals:

public slots:
    void save();
};

#endif // OPTIONS_H
